error_messages = {
    'type_invalid': 'Expected value of type %s, found %s',
    'field_type_invalid': 'Expected value of type %s for %s field, found %s',
    'length_invalid': 'value is not of required length',
    'object_length_invalid': 'object does not have required number of elements',
    'not_in_options': 'value not in list of options',
    'not_excluded': 'field contains non-permitted values',
    'missing_required_data': 'field missing required data',
    'missing_required_keys': 'dictionary missing required keys',
    'missing_required_values': 'object missing required values',
    'does_not_match_regex': 'data does not satisfy required conditions',
    'does_not_startwith': 'data does not start with required value',
    'does_not_endwith': 'data does not end with required value',
    'number_not_in_range': 'number out of range',
    'date_not_in_range': 'date out of range',
    'string_not_in_range': 'invalid string length',
    'list_or_tuple_not_in_range': 'object does not contain required number of items',
    'invalid_date': 'value is not a valid datetime string',
    'invalid_email': 'invalid email',
    'not_even': 'value is not an even number',
    'not_odd': 'value is not an odd number',
    'unkown_exception': 'Unknown exception in %s: %s',
    'missing_value': 'value is missing',
    'invalid_object': 'object does not match expected type',
    'no_error_message': 'Please set an error message',
}